@@ -1,7 +1,6 @@
 # handles all the file operations
 import os
 import json
-from typing import DefaultDict
 from .validation import is_valid_hostname
 
 
@@ -55,14 +54,14 @@ def gen_config():
     )
     PORT = input("Enter ports here: ")
     if PORT == "":
-        PORT = "80; [::]:80"
+        PORT = "80, [::]:80"
     PORT = PORT.split(",")
 
     # root folder
     print()
     ROOT = input(f"Enter the www root path(default /var/www/html/{URL}):  ")
     if ROOT == "":
-        ROOT = f"/var/www/html{URL}"
+        ROOT = f"/var/www/html/{URL}"
 
     # proxy pass
     print()
@@ -117,7 +116,7 @@ def write_config(path, data: list):
     # data = [line  for line in data]
     try:
         with open(path, "w") as f:
-            f.writelines(data)
+            f.writelines([line + os.linesep for line in data])
         return True
     except OSError:
         print()
@@ -142,7 +141,7 @@ def handle_config(data: dict):
             stan_data[key] = data[key]
         except KeyError:
             print(f"Unknown key {key} found. Please refer to our documentation")
-    
+
     data = stan_data
     mandatory_fields = ["url"]
     if not all([x for x in mandatory_fields if x in data]):
@@ -174,4 +173,4 @@ def standard_config():
         "proxy": False,
         "ssl_cert_path": False,
         "ssl_key_path": False,
-    }
\ No newline at end of file
+    }
